@@ -10,7 +10,7 @@
 #        NOTES:  --- The intent of this module is to localize some of the HTML
 #                    generation so as to make it accessible to the test suite.
 #       AUTHOR:  Geoffrey Leach, <geoff@hughes.net>
-#      VERSION:   1.1.9
+#      VERSION:   1.1.11
 #      CREATED:  10/17/07 15:14:33 PDT
 #      UPDATED:  Wed Jan 20 05:28:34 PST 2013
 #    COPYRIGHT:  (c) 2008-2010 Geoffrey Leach
@@ -23,7 +23,7 @@ use 5.006002;
 use strict;
 use warnings;
 use English qw{ -no_match_vars };
-use version; our $VERSION = qv('1.1.10');
+our $VERSION = version->declare("v1.1.11");    
 
 use Exporter::Easy (
     OK => [
@@ -50,10 +50,10 @@ sub headend { return q{</head>}; }
 sub gen {
     my ( $ver, $pver ) = @_;
     my $g
-        = q{<meta name="generator" content="Pod::HtmlEasy/VER Pod::Parser/PVER }
+        = q{<meta name="generator" content="Pod::HtmlEasy/VERSION Pod::Parser/PVERSION }
         . qq{Perl/$] [$^O]">};
-    $g =~ s{VER}{$ver}msx;
-    $g =~ s{PVER}{$pver}msx;
+    $g =~ s{VERSION}{$ver}msx;
+    $g =~ s{PVERSION}{$pver}msx;
     return $g;
 }
 
